@@ -8,5 +8,9 @@ from LinuxServerStatsTelegramBot.sender.TelegramSender import TelegramSender
 @click.command()
 def notify_server_stats():
     DI.set_sender(TelegramSender())
-    Invoker.send_server_stats()
-    print("Notifying server stats testing mode")
+    Invoker.send_server_stats_as_images()
+    Invoker.send_server_stats_as_text()
+
+
+if __name__ == "__main__":
+    notify_server_stats()
